@@ -54,17 +54,17 @@ class thread_safe_socket_map (dict):
 
 	def items (self):
 		with self.lock:
-			v = dict.items (self)
+			v = list (dict.items (self))
 		return v
 
 	def keys (self):
 		with self.lock:
-			v = dict.keys (self)
+			v = list (dict.keys (self))
 		return v
 
 	def values (self):
 		with self.lock:
-			v = dict.values (self)
+			v = list (dict.values (self))
 		return v
 
 
