@@ -92,7 +92,10 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 			if self.cur is None:
 				self.create_cursor ()
 			self.set_event_time ()
-			self.cur.execute (self.out_buffer)
+			try:
+				self.cur.execute (self.out_buffer)
+			except:
+				self.handle_error ()
 			self.out_buffer = ""
 
 	#-----------------------------------
@@ -107,12 +110,15 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 
 	def close_cursor (self):
 		if self.cur:
-			try:
-				self.cur.close ()
-			except:
-				self.handle_error ()
+			try: self.cur.close ()
+			except: pass
 			self.cur = None
 
+	def close (self):
+		self.close_cursor ()
+		asyncore.dispatcher.close (self)
+		dbconnect.AsynDBConnect.close (self)
+
 	def end_tran (self):
 		if self.request:
 			description, data = self.cur and self.cur.description or None, None
@@ -125,7 +131,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 					data = None
 			self.request.handle_result (description or None, self.expt, data)
 			self.request = None
-		self.close_cursor ()
+		not self._closed and self.close_cursor ()
 		dbconnect.AsynDBConnect.end_tran (self)
 
 	def fetchall (self):
@@ -133,11 +139,6 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		self.result = False
 		return data
 
-	def close (self, deactive = 1):
-		self.close_cursor ()
-		asyncore.dispatcher.close (self)
-		dbconnect.AsynDBConnect.close (self, deactive)
-
 	def connect (self, force = 0):
 		self.connecting = True
 		self.connected = False
@@ -168,13 +169,10 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		dbconnect.DBConnect.begin_tran (self, request)
 		self.out_buffer = self._compile (request)
 		if not self.connected and not self.connecting:
-			self.connect ()
-		else:
-			state = self.poll ()
-			if state != POLL_OK:
-				self.reconnect ()
-			else:
-				self.create_cursor ()
+			return self.connect ()
+		if self.poll () == POLL_OK:
+			self.create_cursor ()
+
 
 _AsynConnect = AsynConnect # for subclassing
 
