@@ -24,6 +24,9 @@ class ConnectProxy (baseconnect.ConnectProxy):
 
 
 class DBConnect (baseconnect.BaseConnect):
+    # BASIC RULE: MUST BE CALLED 1 of 2:
+    # 1. close() on error
+    # 2. end_tran() on success
     def __init__ (self, address, params = None, lock = None, logger = None):
         super ().__init__ (lock, logger)
         self.address = address
@@ -67,17 +70,26 @@ class DBConnect (baseconnect.BaseConnect):
 
     def handle_abort (self):
         # call by dist_call
+        self.request = None
         self.close ()
 
-    def close (self, deactive = True):
+    def close (self):
         if self._closed:
             return
         self._closed = True
+        if not self.request:
+            return self.set_active (False)
+        if not self.expt:
+            # disconnect intentionally
+            return
         addr = type (self.address) is tuple and ("%s:%d" % self.address) or str (self.address)
         self.logger ("[info] ..dbo %s has been closed" % addr)
-        if deactive:
-            self.request = None
-            self.set_active (False)
+        self.end_tran ()
+
+    def end_tran (self):
+        # MUST CALL ONLY SUCCESSE, otherwaise already called by self.close ()
+        self.request = None
+        self.set_active (False)
 
     def clean_shutdown_control (self, phase, time_in_this_phase):
         self._no_more_request = True
@@ -104,7 +116,8 @@ class DBConnect (baseconnect.BaseConnect):
 
     def disconnect (self):
         # keep request and active, just close temporary
-        self.close (deactive = False)
+        self.expt = None
+        self.close ()
 
     def isconnected (self):
         # self.connected should be defined at __init__ or asyncore
@@ -129,10 +142,6 @@ class DBConnect (baseconnect.BaseConnect):
         if self.expt is None:
             self.expt = expt
         self.close ()
-        self.end_tran ()
-
-    def end_tran (self):
-        self.isactive () and self.set_active (False)
 
     #-----------------------------------------------------
     # DB methods
@@ -174,5 +183,5 @@ class AsynDBConnect (DBConnect):
 
     def end_tran (self):
         super ().end_tran ()
-        if not self.backend:
+        if not self._closed and not self.backend:
             self.del_channel ()
