@@ -24,7 +24,7 @@ class SynConnect (asynpsycopg2.AsynConnect):
 	def del_channel (self, map=None):
 		pass
 
-	def close (self, deactive = 1):
+	def close (self):
 		if self.cur:
 			self.cur.close ()
 			self.cur = None
@@ -32,7 +32,7 @@ class SynConnect (asynpsycopg2.AsynConnect):
 			self.conn.close ()
 			self.conn = None
 		self.connected = False
-		dbconnect.DBConnect.close (self, deactive)
+		dbconnect.DBConnect.close (self)
 
 	def connect (self):
 		try:
