@@ -1,6 +1,6 @@
 import re
 from . import http_date, http_util
-from ...lib import compressors, attrdict
+from rs4 import compressors, attrdict
 import time
 import json
 import struct
@@ -84,7 +84,7 @@ class Response:
 		ct = self.get_header ('content-type')
 		if not ct:
 			return
-			
+
 		acs = []
 		for each in ac.split (","):
 			a = each.split (";", 1)[0].strip ()
@@ -357,8 +357,7 @@ class Response:
 				
 		self.p.close ()
 		result = self.u.close ()
-		ct = self.get_header ("content-type")
-		
+		ct = self.get_header ("content-type", "")		
 		if self.is_xmlrpc_return:
 			if len (result) == 1:
 				result = result [0]
@@ -382,6 +381,12 @@ class Response:
 				return msgs [0]
 			return msgs
 		
+		elif ct.startswith ('text/'):
+			return self.text
+
+		else:
+			return self.binary
+		
 		self.__data_cache = result	
 		return result
 	
