@@ -13,7 +13,7 @@ import ssl
 import ipaddress
 import time
 from aioquic.h3.events import DataReceived, H3Event, HeadersReceived, PushPromiseReceived
-from .events import PushCanceled, MaxPushIdReceived, DuplicatePushReceived
+from .events import PushCanceled, MaxPushIdReceived
 import random
 
 class ConnectionClosed (Exception):
